==> qtjambi-qt3drender-6.2.2-sources.jar: io/qt/qt3d/render/QCameraSelector.java <==
package io.qt.qt3d.render;


/**
 * <p>Class to allow for selection of camera to be used</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qcameraselector.html">Qt3DRender::QCameraSelector</a></p>
 */
public class QCameraSelector extends io.qt.qt3d.render.QFrameGraphNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCameraSelector.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcameraselector.html#camera-prop">Qt3DRender::QCameraSelector::cameraChanged(Qt3DCore::QEntity*)</a></p>
     */
    @SuppressWarnings({"exports"})
    @io.qt.QtPropertyNotify(name="camera")
    public final Signal1<io.qt.qt3d.core.QEntity> cameraChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QCameraSelector(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QCameraSelector() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcameraselector.html#QCameraSelector">Qt3DRender::QCameraSelector::QCameraSelector(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QCameraSelector(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCameraSelector instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcameraselector.html#camera-prop">Qt3DRender::QCameraSelector::camera()const</a></p>
     */
    @io.qt.QtPropertyReader(name="camera")
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QEntity camera(){
        return camera_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QEntity camera_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcameraselector.html#camera-prop">Qt3DRender::QCameraSelector::setCamera(Qt3DCore::QEntity*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="camera")
    @SuppressWarnings({"exports"})
    public final void setCamera(io.qt.qt3d.core.QEntity camera){
        setCamera_native_Qt3DCore_QEntity_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(camera));
    }
    
    private native void setCamera_native_Qt3DCore_QEntity_ptr(long __this__nativeId, long camera);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QCameraSelector(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QCameraSelector(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QCameraSelector instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.4.1-sources.jar: io/qt/qt3d/render/QCameraSelector.java <==
package io.qt.qt3d.render;


/**
 * <p>Class to allow for selection of camera to be used</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qcameraselector.html">Qt3DRender::QCameraSelector</a></p>
 */
public class QCameraSelector extends io.qt.qt3d.render.QFrameGraphNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCameraSelector.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcameraselector.html#camera-prop">Qt3DRender::QCameraSelector::cameraChanged(Qt3DCore::QEntity*)</a></p>
     */
    @SuppressWarnings({"exports"})
    @io.qt.QtPropertyNotify(name="camera")
    public final Signal1<io.qt.qt3d.core.QEntity> cameraChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QCameraSelector(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QCameraSelector() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcameraselector.html#QCameraSelector">Qt3DRender::QCameraSelector::QCameraSelector(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QCameraSelector(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCameraSelector instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcameraselector.html#camera-prop">Qt3DRender::QCameraSelector::camera()const</a></p>
     */
    @io.qt.QtPropertyReader(name="camera")
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QEntity camera(){
        return camera_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QEntity camera_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcameraselector.html#camera-prop">Qt3DRender::QCameraSelector::setCamera(Qt3DCore::QEntity*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="camera")
    @SuppressWarnings({"exports"})
    public final void setCamera(io.qt.qt3d.core.QEntity camera){
        setCamera_native_Qt3DCore_QEntity_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(camera));
    }
    
    private native void setCamera_native_Qt3DCore_QEntity_ptr(long __this__nativeId, long camera);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QCameraSelector(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QCameraSelector(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QCameraSelector instance, QDeclarativeConstructor constructor);
    
}
